import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { __awaiter } from 'tslib';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { BehaviorSubject, distinctUntilChanged, firstValueFrom, timer } from 'rxjs';

class ElementHighlighterService {
    constructor() {
        this.activeElementSubject = new BehaviorSubject(null);
    }
    //constructor() { }
    get activeElementChanges() {
        return this.activeElementSubject.asObservable();
    }
    setActiveElement(key) {
        this.activeElementSubject.next(key);
    }
    close() {
        this.activeElementSubject.next(null);
    }
}
ElementHighlighterService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
ElementHighlighterService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class ElementHighlighterComponent {
    constructor(elementRef, highlightService, renderer) {
        this.elementRef = elementRef;
        this.highlightService = highlightService;
        this.renderer = renderer;
        this.highlightElement = '';
        this.highlightNext = '';
        this.highlightTooltip = '';
        this._highlightDisableBackdropAutoClose = false;
        this.spHighlightBackDropClick = new EventEmitter();
    }
    //@Input('spHighlightDisableBackdropAutoClose') highlightDisableBackdropAutoClose = false;
    get highlightDisableBackdropAutoClose() { return this._highlightDisableBackdropAutoClose; }
    set highlightDisableBackdropAutoClose(value) {
        this._highlightDisableBackdropAutoClose = coerceBooleanProperty(value);
    }
    ngOnInit() {
        this.highlightSubscription = this.highlightService.activeElementChanges.pipe(distinctUntilChanged()).subscribe(key => {
            console.log(key);
            if (key === this.highlightElement) {
                const boundingRect = this.elementRef.nativeElement.getBoundingClientRect();
                this.elementRef.nativeElement.classList.add('highlighted');
                const overlayEl = this.renderer.createElement('div');
                this.renderer.addClass(overlayEl, 'highlight-overlay');
                if (this.highlightTooltip.length) {
                    const tooltipEl = this.renderer.createElement('div');
                    tooltipEl.innerHTML = this.highlightTooltip;
                    this.renderer.addClass(tooltipEl, 'highlight-tooltip');
                    this.renderer.setStyle(tooltipEl, 'top', `${boundingRect.top - 60}px`);
                    this.renderer.setStyle(tooltipEl, 'left', `${boundingRect.left + (boundingRect.width / 2)}px`);
                    this.renderer.setStyle(tooltipEl, 'transform', `translateX(-50%)`);
                    this.elementRef.nativeElement.after(tooltipEl);
                }
                this.renderer.listen(overlayEl, 'click', (event) => {
                    var _a;
                    if (((_a = this.highlightNext) === null || _a === void 0 ? void 0 : _a.length) || !this._highlightDisableBackdropAutoClose) {
                        this.removeOverlay(true);
                    }
                    const obj = { key: this.highlightElement, event };
                    this.spHighlightBackDropClick.emit(obj);
                });
                this.elementRef.nativeElement.after(overlayEl);
            }
            else {
                if (key !== this.highlightElement) {
                    this.elementRef.nativeElement.classList.remove('highlighted');
                }
                if (key === null) {
                    this.removeOverlay();
                }
            }
        });
    }
    ngOnDestroy() {
        if (this.highlightSubscription) {
            this.highlightSubscription.unsubscribe();
        }
    }
    removeOverlay(showNext = false) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const overlayEl = document.querySelector('.highlight-overlay');
            const tooltipEl = document.querySelector('.highlight-tooltip');
            if (overlayEl) {
                this.renderer.addClass(overlayEl, 'fade-out');
            }
            if (tooltipEl) {
                this.renderer.addClass(tooltipEl, 'fade-out');
            }
            yield firstValueFrom(timer(500));
            overlayEl === null || overlayEl === void 0 ? void 0 : overlayEl.remove();
            tooltipEl === null || tooltipEl === void 0 ? void 0 : tooltipEl.remove();
            if (((_a = this.highlightNext) === null || _a === void 0 ? void 0 : _a.length) && showNext) {
                this.highlightService.setActiveElement(this.highlightNext);
            }
        });
    }
}
ElementHighlighterComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterComponent, deps: [{ token: i0.ElementRef }, { token: ElementHighlighterService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
ElementHighlighterComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.3", type: ElementHighlighterComponent, selector: "[spHighlight]", inputs: { highlightElement: ["spHighlight", "highlightElement"], highlightNext: ["spHighlightNext", "highlightNext"], highlightTooltip: ["spHighlightTooltip", "highlightTooltip"], highlightDisableBackdropAutoClose: ["spHighlightDisableBackdropAutoClose", "highlightDisableBackdropAutoClose"] }, outputs: { spHighlightBackDropClick: "spHighlightBackDropClick" }, ngImport: i0, template: "<ng-content></ng-content>", styles: [":host.highlighted{z-index:9999;position:relative}:host.highlighted~.highlight-tooltip{opacity:1}:host~.highlight-overlay{--animation-duration: .5s;position:fixed;top:0;left:0;right:0;bottom:0;background:rgba(0,0,0,.5);z-index:99;animation:fade-in var(--animation-duration) ease-in-out}:host~.highlight-overlay.fade-out{animation:fade-out var(--animation-duration);opacity:0}:host~.highlight-tooltip{--animation-duration: .5s;z-index:999;position:fixed;background:white;padding:1rem;opacity:0;border-radius:3px;animation:fade-in var(--animation-duration) ease-in-out}:host~.highlight-tooltip:before{content:\"\";width:.5rem;height:.5rem;background-color:#fff;position:absolute;clip-path:polygon(50% 80%,0 0,100% 0);bottom:0;left:50%;transform:translate(-50%,100%)}:host~.highlight-tooltip.fade-out{animation:fade-out var(--animation-duration);opacity:0}@keyframes infinite-pulse{0%{transform:scale(1)}50%{transform:scale(.95)}to{transform:scale(1)}}@keyframes fade-in{0%{opacity:0}to{opacity:1}}@keyframes fade-out{0%{opacity:1}to{opacity:0}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterComponent, decorators: [{
            type: Component,
            args: [{ selector: '[spHighlight]', template: "<ng-content></ng-content>", styles: [":host.highlighted{z-index:9999;position:relative}:host.highlighted~.highlight-tooltip{opacity:1}:host~.highlight-overlay{--animation-duration: .5s;position:fixed;top:0;left:0;right:0;bottom:0;background:rgba(0,0,0,.5);z-index:99;animation:fade-in var(--animation-duration) ease-in-out}:host~.highlight-overlay.fade-out{animation:fade-out var(--animation-duration);opacity:0}:host~.highlight-tooltip{--animation-duration: .5s;z-index:999;position:fixed;background:white;padding:1rem;opacity:0;border-radius:3px;animation:fade-in var(--animation-duration) ease-in-out}:host~.highlight-tooltip:before{content:\"\";width:.5rem;height:.5rem;background-color:#fff;position:absolute;clip-path:polygon(50% 80%,0 0,100% 0);bottom:0;left:50%;transform:translate(-50%,100%)}:host~.highlight-tooltip.fade-out{animation:fade-out var(--animation-duration);opacity:0}@keyframes infinite-pulse{0%{transform:scale(1)}50%{transform:scale(.95)}to{transform:scale(1)}}@keyframes fade-in{0%{opacity:0}to{opacity:1}}@keyframes fade-out{0%{opacity:1}to{opacity:0}}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: ElementHighlighterService }, { type: i0.Renderer2 }]; }, propDecorators: { highlightElement: [{
                type: Input,
                args: ['spHighlight']
            }], highlightNext: [{
                type: Input,
                args: ['spHighlightNext']
            }], highlightTooltip: [{
                type: Input,
                args: ['spHighlightTooltip']
            }], highlightDisableBackdropAutoClose: [{
                type: Input,
                args: ['spHighlightDisableBackdropAutoClose']
            }], spHighlightBackDropClick: [{
                type: Output
            }] } });

class ElementHighlighterModule {
}
ElementHighlighterModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ElementHighlighterModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterModule, declarations: [ElementHighlighterComponent], imports: [CommonModule], exports: [ElementHighlighterComponent] });
ElementHighlighterModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterModule, providers: [ElementHighlighterService], imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.3", ngImport: i0, type: ElementHighlighterModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [ElementHighlighterComponent],
                    exports: [ElementHighlighterComponent],
                    providers: [ElementHighlighterService],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ElementHighlighterComponent, ElementHighlighterModule, ElementHighlighterService };
//# sourceMappingURL=sandstroms-element-highlighter.mjs.map
